.. image:: https://img.shields.io/pypi/v/khartoum.svg
   :target: https://pypi.org/project/khartoum

.. image:: https://img.shields.io/pypi/pyversions/khartoum.svg

.. image:: https://img.shields.io/travis/yougov/khartoum/master.svg
   :target: https://travis-ci.org/yougov/khartoum

.. .. image:: https://img.shields.io/appveyor/ci/yougov/khartoum/master.svg
..    :target: https://ci.appveyor.com/project/yougov/khartoum/branch/master

.. .. image:: https://readthedocs.org/projects/khartoum/badge/?version=latest
..    :target: https://khartoum.readthedocs.io/en/latest/?badge=latest

Khartoum is a simple app for http serving of static files from MongoDB's GridFS filesystem.
